// This is the main login screen. It displays of dropdown list of places where you can get an SSH certificate

import { Component, OnInit } from '@angular/core';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA, MatDialogModule, MatDialogConfig } from '@angular/material/dialog';
import {OverlayContainer} from '@angular/cdk/overlay';
import { TesService } from '../tes.service';
import {BackendSelectionService } from '../backend-selection.service';
import { AuthorisationService } from '../authorisation.service';
import { Identity } from '../identity';
import { ComputesitesService } from '../computesites.service';
import {DomSanitizer} from '@angular/platform-browser';
import {PipeTransform, Pipe} from "@angular/core";
import { LocationStrategy } from '@angular/common';

// This allows us to include html links in the description of each site you can log into
@Pipe({ name: 'safeHtml'})
export class SafeHtmlPipe implements PipeTransform  {
  constructor(private sanitized: DomSanitizer) {}
  transform(value) {
    return this.sanitized.bypassSecurityTrustHtml(value);
  }
}

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.css']
})
export class LoginComponent implements OnInit {
  public authorised: boolean;
  public identity: Identity;
  public identities: Identity[];
  public selectedApiServer: any;
  public selected: any;
  public loggedInAuthZ: any;
  public loggedOutAuthZ: any;


  constructor( public dialog: MatDialog,
                public tesService: TesService,
                public backendSelectionService: BackendSelectionService,
                public authService: AuthorisationService,
                public computeSitesService: ComputesitesService,
                public overlayContainer: OverlayContainer,
                private locationStrategy: LocationStrategy,
                ) {

  }

  ngOnInit() {
    this.authService.loggedInAuthZ$.subscribe((v) => {console.log('loggedin',v); this.loggedInAuthZ = v})
    this.authService.loggedOutAuthZ$.subscribe((v) => { console.log('loggedout',v); this.loggedOutAuthZ = v})
  }

  ngOnDestroy() {

  }

  public login() {
    let authservice = this.selected;
    // Initiate Login
    let redirect_uri = window.location.origin+this.locationStrategy.getBaseHref()+"sshauthz_callback";
    if (redirect_uri.includes("file:///")) {
      redirect_uri = "http://localhost:4200/sshauthz_callback";
    }
    let nonce=Math.random().toString(36).substring(2, 15)
  
    sessionStorage.setItem('authservice', JSON.stringify([authservice,nonce]));
    sessionStorage.setItem('path', '/launch');
    if (authservice.scope == null) {
      window.location.assign(authservice.authorise+"?response_type=token&redirect_uri="+redirect_uri+"&state="+nonce+"&client_id="+authservice.client_id);
    } else {
      window.location.assign(authservice.authorise+"?response_type=token&redirect_uri="+redirect_uri+"&state="+nonce+"&client_id="+authservice.client_id+"&scope="+authservice.scope);
    }
  }

}

